<?php

namespace Teknisa\CADFIN\Controllers;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CADFIN\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\Libs\Service\CRUD as CrudService;
use Teknisa\CADFIN\Services\Ger40100CategoriasDreGerencialService;

/**
 * Class Ger40100CategoriasDreGerencialController
 * @package Teknisa\CADFIN\Controllers
 */
class Ger40100CategoriasDreGerencialController extends TeknisaCrud{

    protected $crudService;
    protected $parameterBag;
    protected $service;

    /**
     * @param CrudService  $crudService
     * @param ParameterBag $parameterBag
     * @param Ger40100CategoriasDreGerencialService $service
     */
    public function __construct(CrudService $crudService, ParameterBag $parameterBag, Ger40100CategoriasDreGerencialService $service)
    {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->service      = $service;
    }
    
    /**
     * Exclui Categoria DRE
     * @param Row $row
     * @param Response $response
     */
    public function removeCategoriaDRE(Row $row, Response $response)
    {
        try {
            $row = $row->getRow();
            
            $nrorg       = $row['NRORG'];
            $cditemestru = $row['CDITEMESTRU'];

            $this->service->removeCategoriaDRE($nrorg, $cditemestru);

            $response->addDataSet(new DataSet('excluiCategoriaDRE', []));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Salva Classificação Financeira - Categoria DRE
     * @param Row $row
     * @param Response $response
     */
    public function salvaClassFinancCategoriaDRE(Row $row, Response $response)
    {
        try {
            $row = $row->getRow();
            
            $nrorg       = $row['NRORG'];
            $cditemestru = $row['CDITEMESTRU'];
            $cdclassfina = $row['CDCLASSFINA'];

            $this->service->atualizaClassFinancCategoriaDRE($nrorg, $cditemestru, $cdclassfina);

            $response->addDataSet(new DataSet('salvaClassFinancCategoriaDRE', []));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Exclui Classificação Financeira - Categoria DRE
     * @param Row $row
     * @param Response $response
     */
    public function excluiClassFinancCategoriaDRE(Row $row, Response $response)
    {
        try {
            $row = $row->getRow();
            
            $nrorg       = $row['NRORG'];
            $cdclassfina = $row['CDCLASSFINA'];
            $cditemestru = '';

            $this->service->atualizaClassFinancCategoriaDRE($nrorg, $cditemestru, $cdclassfina);

            $response->addDataSet(new DataSet('excluiClassFinancCategoriaDRE', []));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

}
