<?php
namespace Teknisa\CADFIN\Services;

use Teknisa\Libs\Util\Environment;
use Teknisa\CADFIN\Factories\Ger08300BancoFactory;

class Ger08300BancoService{

	protected $environment;
	protected $entityManager;
	protected $dataSourceManager;

	public function __construct(Environment $environment, \Doctrine\ORM\EntityManager $entityManager ,$dataSourceManager, $factory){
		$this->environment = $environment;
		$this->entityManager = $entityManager;
		$this->dataSourceManager = $dataSourceManager;
		$this->factory = $factory;
	}

	public function buscar($condicao){
		return $this->dataSourceManager->findBy($condicao);
	}
	
	public function getRowUpdate($row) {
		$currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
        $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
        $row['DTULTATU'] = $currentTime;
        $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
        $row['CDOPERULTATU'] = $this->environment->getCdOperador();
        return $row;
	}
	
	public function buscaBancos($row) {
		if(isset($row['CDBANCO'])) {
			if($row['CDBANCO']) {
				$row['TCDBANCO'] = NULL;
			}
			else {
				$row['TCDBANCO'] = 'T';
			}
		}
		else {
			$row['TCDBANCO'] = 'T';
			$row['CDBANCO']  = NULL;
		}
		if(isset($row['NMBANCO'])) {
			if($row['NMBANCO']) {
				$row['TNMBANCO'] = NULL;
			}
			else {
				$row['TNMBANCO'] = 'T';
			}
		}
		else {
			$row['TNMBANCO'] = 'T';
			$row['NMBANCO']  = NULL;
		}
		
		
		//$row['NMBANCO'] = is_array($row['NMBANCO'])?  $row['NMBANCO'][0]['_ALL'] : $row['NMBANCO'];
		//$row['CDBANCO'] = is_array($row['CDBANCO'])?  $row['CDBANCO'][0]['_ALL'] : $row['CDBANCO'];

		$params = array(':NRORG' => $this->environment->getNrOrgTrab(), 
					':CDBANCO'	 => $row['CDBANCO'],
					':NMBANCO'   => $row['NMBANCO'],
					':TCDBANCO'  => $row['TCDBANCO'],
					':TNMBANCO'  => $row['TNMBANCO']);
		$bancos = $this->factory->getBancos($params);
		$count = 0;
		foreach ($bancos as $banco) {
			$banco['__is_new'] = false;
			$bancos[$count] = $banco;
			$count++;
		}
		return $bancos;
	}
	
	public function saveCNABdata($row) {
		try{
			$params = [];
	        $params['CDEMPBANCPAG'] = $row['CDEMPBANCPAG'];
	        $params['CDEMPBANCREC'] = $row['CDEMPBANCREC'];
	        $params['CDCARTCOBR'] = $row['CDCARTCOBR'];
	        $params['CDINS1COBR'] = $row['CDINS1COBR'];
	        $params['CDINS2COBR'] = $row['CDINS2COBR'];
	        $params['QTDIAPROTEST'] = $row['QTDIAPROTEST'];
	        $params['CDDIAPROTEST'] = $row['CDDIAPROTEST'];
	        $params['IDIMPRBOLETO'] = $row['IDIMPRBOLETO'];
	        $params['TXMENSBOLETO'] = $row['TXMENSBOLETO'];
	        $params['IDCARTCOBR'] = $row['IDCARTCOBR'];
	        $params['IDFORMCADBANC'] = $row['IDFORMCADBANC'];
	        $params['IDLAYEXTBANCO'] = $row['IDLAYEXTBANCO'];
	        $params['NRVARIACARTCOB'] = $row['NRVARIACARTCOB'];
	        $params['IDLAYOUTCNAB'] = $row['IDLAYOUTCNAB'];
	        $params['CDFORNECED'] = $row['CDFORNECED'];
	        $params['CDTPBAIXAPAG'] = $row['CDTPBAIXAPAG'];
	        $params['CDREDUCONT'] = $row['CDREDUCONT'];
	        $params['IDPADRAGENCNABPAG'] = $row['IDPADRAGENCNABPAG'];
	        $params['IDPADRCNABREC'] = $row['IDPADRCNABREC'];
	        $params['IDPADRCNABPAG'] = $row['IDPADRCNABPAG'];
	        $params['CDEMPRESA'] = $row['CDEMPRESA'];
	        $params['CDBANCO'] = $row['CDBANCO'];
	        return $this->factory->saveCNABdata($params);
		} catch (\Exception $e) {
            throw $e;
		}
	}
	
}